summaryrefslogtreecommitdiff
path: root/util/bind.sh
diff options
context:
space:
mode:
authorThomas Markwalder <tmark@isc.org>2018-09-14 13:41:41 -0400
committerThomas Markwalder <tmark@isc.org>2018-09-14 13:41:41 -0400
commit8194daabfd590f17825f0c61e9534bee5c99cc86 (patch)
tree3678f349c7304d00363372134a50332dd8e93c3e /util/bind.sh
parentb1ed27b95152c128d735eb36c42cc5c35e001ae2 (diff)
downloadisc-dhcp-8194daabfd590f17825f0c61e9534bee5c99cc86.tar.gz
[master] Added includes of new BIND9 compatibility headers, updated util/bind.sh
Merges in rt48072.
Diffstat (limited to 'util/bind.sh')
-rw-r--r--util/bind.sh34
1 files changed, 26 insertions, 8 deletions
diff --git a/util/bind.sh b/util/bind.sh
index 4e986ea0..b813044a 100644
--- a/util/bind.sh
+++ b/util/bind.sh
@@ -27,11 +27,20 @@
topdir=`pwd`
binddir=$topdir/bind
-remote=--remote=repo.isc.org:/proj/git/prod/bind9.git
+
+# repo_host and repo_path are used together to from urls for wget calls
+# to fetch the version and kit.sh files, and then also as the --remote
+# argument passed into kit.sh
+repo_host="gitlab.isc.org"
+repo_path="isc-projects/bind9"
case "${1:-}" in
---remote=*)
- remote="${1}";
+--repo_host=*)
+ repo_host="${1}";
+ shift
+ ;;
+--repo_path=*)
+ repo_path="${1}";
shift
;;
esac
@@ -95,7 +104,7 @@ case $# in
;;
esac
;;
*) echo "usage: sh bind.sh [--remote=<path>] [<branch>|<version>]" >&2
exit 1
;;
esac
@@ -119,18 +128,27 @@ else
cd $binddir
# Get the bind version file and move it to version.tmp
- git archive --format tar $remote $BINDTAG version | tar xf -
+ wget https://$repo_host/$repo_path/raw/$BINDTAG/version
mv version version.tmp
+ if [ $? -ne 0 ]
+ then
+ echo "Fetch of version file failed"
+ exit -1
+ fi
# Get the bind release kit shell script
- git archive --format tar $remote master:util/ | tar xf - kit.sh
+ wget https://$repo_host/$repo_path/raw/master/util/kit.sh
+ if [ $? -ne 0 ]
+ then
+ echo "Fetch of kit.sh failed"
+ exit -1
+ fi
# Create the bind tarball, which has the side effect of
# setting up the bind directory we will use for building
# the libraries
echo Creating tarball for $BINDTAG
- sh kit.sh $remote $SNAP $BINDTAG $binddir
-
+ sh kit.sh --remote="git@$repo_host:$repo_path.git" $SNAP $BINDTAG $binddir
. ./version.tmp
version=${MAJORVER}.${MINORVER}.${PATCHVER}${RELEASETYPE}${RELEASEVER}
@@ -95,7 +104,7 @@ case $# in
esac
;;
- *) echo "usage: sh bind.sh [--remote=<path>] [<branch>|<version>]" >&2
+ *) echo "usage: sh bind.sh [--repo_host=<host>] [--repo_path=<project path>] [<branch>|<version>]" >&2
exit 1
;;